@@ -18,17 +18,17 @@ pub struct CreateIndex<'info> {
         init, 
         seeds = [
             state::SEED_INDEX, 
-            signer.key().as_ref(), 
+            owner.key().as_ref(), 
             namespace.as_ref()
         ],
         bump = bump, 
-        payer = signer, 
+        payer = owner, 
         space = 8 + size_of::<state::Index>()
     )]
     pub index: Account<'info, state::Index>,
 
     #[account(mut)]
-    pub signer: Signer<'info>,
+    pub owner: Signer<'info>,
     
     #[account(address = system_program::ID)]
     pub system_program: Program<'info, System>,
@@ -42,10 +42,10 @@ pub fn handler(
 ) -> ProgramResult {
     // Get accounts.
     let index = &mut ctx.accounts.index;
-    let signer = &ctx.accounts.signer;
+    let owner = &ctx.accounts.owner;
 
     // Initialize index account.
-    index.owner = signer.key();
+    index.owner = owner.key();
     index.namespace = namespace;
     index.count = 0;
     index.is_serial = is_serial;
