@@ -1,13 +1,14 @@
 use anchor_lang::prelude::*;
 
-/// Root seed for Index accounts.
+/// Root seed for deriving Index account PDAs.
 pub const SEED_INDEX: &[u8] = b"idx";
 
-/// Index accounts manage the metadata of index including its owner, namespace, and item count.
+/// Index accounts store an index's metadata.
 #[account]
 pub struct Index {
     pub owner: Pubkey,
     pub namespace: String,
-    pub item_count: u128,
+    pub count: u128,
+    pub is_serial: bool,
     pub bump: u8,
 }
